/*
** Zabbix
** Copyright (C) 2001-2024 Zabbix SIA
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
**/

package main

import (
	"fmt"
	"time"

	"zabbix.com/internal/agent"
	"zabbix.com/internal/agent/scheduler"
)

func checkMetric(s scheduler.Scheduler, metric string) {
	const timeoutForTestrunChecks = time.Minute

	value, err := s.PerformTask(metric, timeoutForTestrunChecks, agent.TestrunClientID)
	if err != nil {
		fmt.Printf("%-46s[m|ZBX_NOTSUPPORTED] [%s]\n", metric, err.Error())
	} else {
		fmt.Printf("%-46s[s|%s]\n", metric, value)
	}
}
